@@ -13,26 +13,32 @@ Every widget has following methods and attributes:
 from enum import Enum
 from PySide6.QtCore import Signal, Qt
 from PySide6.QtGui import QValidator, QIntValidator, QDoubleValidator
-from PySide6.QtWidgets import (QWidget, QCheckBox, QLineEdit, QComboBox,
-    QGroupBox, QHBoxLayout)
-from typing import List, Union, Any, Type, Optional
+from PySide6.QtWidgets import (
+    QCheckBox,
+    QLineEdit,
+    QComboBox,
+    QGroupBox,
+    QHBoxLayout,
+)
+from typing import List, Union, Any, Type, Optional, TypeVar
+from .typing import DataWidgetProtocol
 
 
 __all__ = [
-    'type2Widget',
-    'BoolCheckBox',
-    'MISSING',
-    'EmptyIntValidator',
-    'IntLineEdit',
-    'EmptyFloatValidator',
-    'FloatLineEdit',
-    'StrLineEdit',
-    'TupleGroupBox',
-    'EnumComboBox',
+    "type2Widget",
+    "BoolCheckBox",
+    "MISSING",
+    "EmptyIntValidator",
+    "IntLineEdit",
+    "EmptyFloatValidator",
+    "FloatLineEdit",
+    "StrLineEdit",
+    "TupleGroupBox",
+    "EnumComboBox",
 ]
 
 
-def type2Widget(t: Any) -> QWidget:
+def type2Widget(t: Any) -> DataWidgetProtocol:
     """Return the widget instance for given type annotation."""
     if isinstance(t, type) and issubclass(t, Enum):
         return EnumComboBox.fromEnum(t)
@@ -44,31 +50,29 @@ def type2Widget(t: Any) -> QWidget:
         return FloatLineEdit()
     if isinstance(t, type) and issubclass(t, str):
         return StrLineEdit()
-    origin = getattr(t, '__origin__', None)
+    origin = getattr(t, "__origin__", None)  # t is Tuple[]
     if origin is tuple:
-        args = getattr(t, '__args__', None)
+        args = getattr(t, "__args__", None)
         if args is None:
-            raise TypeError('%s does not have argument type' % t)
+            raise TypeError("%s does not have argument type" % t)
         if Ellipsis in args:
-            txt = 'Number of arguments of %s not fixed' % t
+            txt = "Number of arguments of %s not fixed" % t
             raise TypeError(txt)
         widgets = [type2Widget(arg) for arg in args]
         return TupleGroupBox.fromWidgets(widgets)
-    elif origin is Union:
-        args = [a for a in getattr(t, '__args__') if a is not type(None)]
+    if origin is Union:
+        args = [a for a in getattr(t, "__args__") if not isinstance(None, a)]
         if len(args) > 1:
-            msg = f'Cannot convert Union with multiple types: {t}'
+            msg = f"Cannot convert Union with multiple types: {t}"
             raise TypeError(msg)
-        arg, = args
-        if isinstance(arg, type) and issubclass(arg, bool):
-            widget = type2Widget(arg)
+        widget = type2Widget(args[0])
+        if isinstance(widget, BoolCheckBox):
             widget.setTristate(True)
             return widget
-        if isinstance(arg, type) and issubclass(arg, (int, float)):
-            widget = type2Widget(arg)
+        if isinstance(widget, (IntLineEdit, FloatLineEdit)):
             widget.setDefaultDataValue(None)
             return widget
-    raise TypeError('Unknown type or annotation: %s' % t)
+    raise TypeError("Unknown type or annotation: %s" % t)
 
 
 class BoolCheckBox(QCheckBox):
@@ -100,7 +104,8 @@ class BoolCheckBox(QCheckBox):
     >>> runGUI() # doctest: +SKIP
 
     """
-    dataValueChanged = Signal(object) # bool or None
+
+    dataValueChanged = Signal(object)  # bool or None
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -145,15 +150,18 @@ class BoolCheckBox(QCheckBox):
 
 class _MISSING_TYPE:
     """Sentinel object to detect if the default value is set or not."""
+
     pass
 
+
 MISSING = _MISSING_TYPE()
 
 
 class EmptyIntValidator(QIntValidator):
     """Validator which accpets integer and empty string"""
+
     def validate(self, input: str, pos: int) -> QValidator.State:
-        ret: QValidator.State = super().validate(input, pos) # type: ignore
+        ret: QValidator.State = super().validate(input, pos)  # type: ignore
         if not input:
             ret = QValidator.Acceptable
         return ret
@@ -183,6 +191,7 @@ class IntLineEdit(QLineEdit):
     ...     app.quit()
     >>> runGUI() # doctest: +SKIP
     """
+
     dataValueChanged = Signal(object)
 
     def __init__(self, parent=None):
@@ -232,7 +241,7 @@ class IntLineEdit(QLineEdit):
             val = self.defaultDataValue()
         else:
             name = self.dataName() or str(self)
-            raise TypeError('Missing data for %s' % name)
+            raise TypeError("Missing data for %s" % name)
         return val
 
     def defaultDataValue(self) -> Any:
@@ -287,7 +296,7 @@ class IntLineEdit(QLineEdit):
         If the new value is same as the default value, empty str is set.
         """
         if value == self.defaultDataValue():
-            self.setText('')
+            self.setText("")
         else:
             self.setText(str(value))
         self.emitDataValueChanged()
@@ -306,8 +315,9 @@ class IntLineEdit(QLineEdit):
 
 class EmptyFloatValidator(QDoubleValidator):
     """Validator which accpets float and empty string"""
+
     def validate(self, input: str, pos: int) -> QValidator.State:
-        ret: QValidator.State = super().validate(input, pos) # type: ignore
+        ret: QValidator.State = super().validate(input, pos)  # type: ignore
         if not input:
             ret = QValidator.Acceptable
         return ret
@@ -337,6 +347,7 @@ class FloatLineEdit(QLineEdit):
     ...     app.quit()
     >>> runGUI() # doctest: +SKIP
     """
+
     dataValueChanged = Signal(object)
 
     def __init__(self, parent=None):
@@ -386,7 +397,7 @@ class FloatLineEdit(QLineEdit):
             val = self.defaultDataValue()
         else:
             name = self.dataName() or str(self)
-            raise TypeError('Missing data for %s' % name)
+            raise TypeError("Missing data for %s" % name)
         return val
 
     def defaultDataValue(self) -> Any:
@@ -441,7 +452,7 @@ class FloatLineEdit(QLineEdit):
         If the new value is same as the default value, empty str is set.
         """
         if value == self.defaultDataValue():
-            self.setText('')
+            self.setText("")
         else:
             self.setText(str(value))
         self.emitDataValueChanged()
@@ -483,6 +494,7 @@ class StrLineEdit(QLineEdit):
     ...     app.quit()
     >>> runGUI() # doctest: +SKIP
     """
+
     dataValueChanged = Signal(str)
 
     def __init__(self, parent=None):
@@ -508,6 +520,9 @@ class StrLineEdit(QLineEdit):
         self.dataValueChanged.emit(self.text())
 
 
+T = TypeVar("T", bound="TupleGroupBox")
+
+
 class TupleGroupBox(QGroupBox):
     """
     Widget to represent the tuple data with fixed number of items.
@@ -540,10 +555,11 @@ class TupleGroupBox(QGroupBox):
     >>> runGUI() # doctest: +SKIP
 
     """
+
     dataValueChanged = Signal(tuple)
 
     @classmethod
-    def fromWidgets(cls, widgets: List[QWidget]) -> 'TupleGroupBox':
+    def fromWidgets(cls: Type[T], widgets: List[DataWidgetProtocol]) -> T:
         obj = cls()
         obj._widgets = widgets
         obj.initWidgets()
@@ -561,7 +577,7 @@ class TupleGroupBox(QGroupBox):
         self.setTitle(name)
         self.setToolTip(name)
 
-    def widgets(self) -> List[QWidget]:
+    def widgets(self) -> List[DataWidgetProtocol]:
         return self._widgets
 
     def initWidgets(self):
@@ -590,6 +606,9 @@ class TupleGroupBox(QGroupBox):
             pass
 
 
+V = TypeVar("V", bound="EnumComboBox")
+
+
 class EnumComboBox(QComboBox):
     """
     Combo box for enum type.
@@ -628,10 +647,11 @@ class EnumComboBox(QComboBox):
     >>> runGUI() # doctest: +SKIP
 
     """
+
     dataValueChanged = Signal(Enum)
 
     @classmethod
-    def fromEnum(cls, enum: Type[Enum]) -> 'EnumComboBox':
+    def fromEnum(cls: Type[V], enum: Type[Enum]) -> V:
         obj = cls()
         for e in enum:
             obj.addItem(e.name, userData=e)
